@@ -37,7 +37,6 @@ from shapely.geometry import shape
 import udlai
 
 token = os.environ.get("TOKEN")
-token = "6a617a9a72f1babaeb0451950633a39974a77019"
 
 
 def test_attributes():
@@ -107,6 +106,13 @@ class TestFeatures:
             assert c in r.columns
         assert r["net_betw_speed"].notna().sum() == 2
 
+    def test_grid_size(self):
+        r25 = udlai.features(token, 47.37, 8.54, [113, 172], index_by="name")
+        r675 = udlai.features(
+            token, 47.37, 8.54, [113, 172], index_by="name", grid_size=675
+        )
+        assert r25["net_betw_speed"] != r675["net_betw_speed"]
+
 
 class TestAggregate:
     def setup_method(self):
@@ -155,7 +161,7 @@ class TestAggregate:
         for c in ["max", "mean", "median", "min", "std", "sum"]:
             assert c in r.columns
         assert r.loc["net_betw_speed"].notna().sum() == 6
-        assert r.loc["Leisure activties in 300m"].notna().sum() == 6
+        assert r.loc["freiz_300"].notna().sum() == 6
 
     def test_single_geojson(self):
         r = udlai.aggregates(token, self.geojson, 113)
